@@ -12,8 +12,10 @@ import functools
 
 import six
 
+__metaclass__ = type
 
-class Parser(object):
+
+class Parser:
 	"""
 	Datetime parser: parses a date-time string using multiple possible
 	formats.
@@ -136,7 +138,7 @@ def strptime(s, fmt, tzinfo=None):
 	return datetime.datetime(tzinfo=tzinfo, *res[:6])
 
 
-class DatetimeConstructor(object):
+class DatetimeConstructor:
 	"""
 	>>> cd = DatetimeConstructor.construct_datetime
 	>>> cd(datetime.datetime(2011,1,1))
@@ -401,7 +403,7 @@ def calculate_prorated_values():
 	unit time), and return that same rate for various time periods.
 	"""
 	rate = six.moves.input("Enter the rate (3/hour, 50/month)> ")
-	res = re.match('(?P<value>[\d.]+)/(?P<period>\w+)$', rate).groupdict()
+	res = re.match(r'(?P<value>[\d.]+)/(?P<period>\w+)$', rate).groupdict()
 	value = float(res['value'])
 	value_per_second = value / get_period_seconds(res['period'])
 	for period in ('minute', 'hour', 'day', 'month', 'year'):
@@ -444,7 +446,7 @@ def parse_timedelta(str):
 
 
 def _parse_timedelta_part(part):
-	match = re.match('(?P<value>[\d.]+) (?P<unit>\w+)', part)
+	match = re.match(r'(?P<value>[\d.]+) (?P<unit>\w+)', part)
 	if not match:
 		msg = "Unable to parse {part!r} as a time delta".format(**locals())
 		raise ValueError(msg)
